import createApp from '../../util/express-app';
import createAuthenticatedHandler from '../../util/create-authenticated-handler';
import { RequestContext } from '../../util/request-context.type';
import { Response } from 'express';
import { getErrorMessage } from '../../util/error-message';
import { getChartsByMd5, getChartsBySha256 } from './chart.service';
import { flatten, uniqBy } from 'lodash-es';

const app = createApp();
export const handler = createAuthenticatedHandler(app);

app.post('/chart/public', [
  async (req: RequestContext, res: Response) => {
    try {
      const { md5 = [], sha256 = [] } = req.body as {
        md5: string[];
        sha256: string[];
      };

      const md5Charts = flatten(
        await Promise.all(md5.map((md5) => getChartsByMd5(md5))),
      );
      const md5ChartsFound = md5Charts.map((chart) => chart.md5);
      const md5ChartsNotFound = md5.filter(
        (md5) => !md5ChartsFound.includes(md5),
      );

      const sha256Charts = flatten(
        await Promise.all(sha256.map((sha256) => getChartsBySha256(sha256))),
      );
      const sha256ChartsFound = sha256Charts.map((chart) => chart.sha256);
      const sha256ChartsNotFound = sha256.filter(
        (sha256) => !sha256ChartsFound.includes(sha256),
      );

      res.json({
        resources: uniqBy([...md5Charts, ...sha256Charts], 'resourceUri').map(
          (chart) => chart.resourceUri,
        ),
        metadata: {
          success: [...md5ChartsFound, ...sha256ChartsFound],
          failure: [...md5ChartsNotFound, ...sha256ChartsNotFound],
        },
      });
    } catch (error) {
      const message = getErrorMessage(error);
      console.error(`Failed to get charts ${message}`);
      res.status(400).json({ error: 'Failed to get charts' });
    }
  },
]);
